summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorjbj <devnull@localhost>2004-10-20 10:19:34 +0000
committerjbj <devnull@localhost>2004-10-20 10:19:34 +0000
commit8faa61c020369ecf850a823a505b946485fa1bea (patch)
tree7f02c8530203569735c68dffc4e93a08d16d7edf /lib
parent2c192f3e33ef5237c6b00a9962c112c2bd304464 (diff)
downloadlibrpm-tizen-8faa61c020369ecf850a823a505b946485fa1bea.tar.gz
librpm-tizen-8faa61c020369ecf850a823a505b946485fa1bea.tar.bz2
librpm-tizen-8faa61c020369ecf850a823a505b946485fa1bea.zip
Doxygen fiddles.
CVS patchset: 7495 CVS date: 2004/10/20 10:19:34
Diffstat (limited to 'lib')
-rw-r--r--lib/cpio.h2
-rw-r--r--lib/depends.c1
-rw-r--r--lib/rpmgi.h13
-rw-r--r--lib/rpmlib.h18
-rw-r--r--lib/rpmts.h2
-rw-r--r--lib/signature.h6
-rw-r--r--lib/transaction.c16
7 files changed, 31 insertions, 27 deletions
diff --git a/lib/cpio.h b/lib/cpio.h
index b7362f138..c716097da 100644
--- a/lib/cpio.h
+++ b/lib/cpio.h
@@ -91,7 +91,7 @@ struct cpioCrcPhysicalHeader {
char checksum[8]; /* ignored !! */
};
-#define PHYS_HDR_SIZE 110 /*!< Don't depend on sizeof(struct) */
+#define PHYS_HDR_SIZE 110 /* Don't depend on sizeof(struct) */
#ifdef __cplusplus
extern "C" {
diff --git a/lib/depends.c b/lib/depends.c
index 8208cf816..a7d132e9f 100644
--- a/lib/depends.c
+++ b/lib/depends.c
@@ -946,6 +946,7 @@ static inline /*@observer@*/ const char * const identifyDepend(int_32 f)
* @param requires relation
* @param zap max. no. of co-requisites to remove (-1 is all)?
* @retval nzaps address of no. of relations removed
+ * @param msglvl message level at which to spew
* @return (possibly NULL) formatted "q <- p" releation (malloc'ed)
*/
/*@-boundswrite@*/
diff --git a/lib/rpmgi.h b/lib/rpmgi.h
index e0d9d8bb1..ac883dbd0 100644
--- a/lib/rpmgi.h
+++ b/lib/rpmgi.h
@@ -2,7 +2,7 @@
#define H_RPMGI
/** \ingroup rpmio
- * \file rpmio/rpmgi.h
+ * \file lib/rpmgi.h
*/
#include <rpmlib.h>
@@ -105,10 +105,13 @@ rpmgi rpmgiFree(/*@killref@*/ /*@only@*/ /*@null@*/ rpmgi gi)
/*@globals rpmGlobalMacroContext, h_errno, internalState @*/
/*@modifies gi, rpmGlobalMacroContext, h_errno, internalState @*/;
-/** Create a generalized iterator.
- * @param argv iterator argv array
- * @param flags iterator flags
- * @return new general iterator
+/**
+ * Return a generalized iterator.
+ * @param ts transaction set
+ * @param tag rpm tag
+ * @param keyp key data (NULL for sequential access)
+ * @param keylen key data length (0 will use strlen(keyp))
+ * @return new iterator
*/
/*@null@*/
rpmgi rpmgiNew(rpmts ts, int tag, /*@null@*/ const void * keyp, size_t keylen)
diff --git a/lib/rpmlib.h b/lib/rpmlib.h
index b6c714088..0a2447092 100644
--- a/lib/rpmlib.h
+++ b/lib/rpmlib.h
@@ -214,15 +214,15 @@ extern const struct headerSprintfExtension_s rpmHeaderFormats[];
/**
* Pseudo-tags used by the rpmdb and rpmgi iterator API's.
*/
-#define RPMDBI_PACKAGES 0 /*!< Installed package headers. */
-#define RPMDBI_DEPENDS 1 /*!< Dependency resolution cache. */
-#define RPMDBI_LABEL 2 /*!< Fingerprint search marker. */
-#define RPMDBI_ADDED 3 /*!< Added package headers. */
-#define RPMDBI_REMOVED 4 /*!< Removed package headers. */
-#define RPMDBI_AVAILABLE 5 /*!< Available package headers. */
-#define RPMDBI_HDLIST 6 /*!< (rpmgi) Header list. */
-#define RPMDBI_ARGLIST 7 /*!< (rpmgi) Argument list. */
-#define RPMDBI_FTSWALK 8 /*!< (rpmgi) File tree walk. */
+#define RPMDBI_PACKAGES 0 /* Installed package headers. */
+#define RPMDBI_DEPENDS 1 /* Dependency resolution cache. */
+#define RPMDBI_LABEL 2 /* Fingerprint search marker. */
+#define RPMDBI_ADDED 3 /* Added package headers. */
+#define RPMDBI_REMOVED 4 /* Removed package headers. */
+#define RPMDBI_AVAILABLE 5 /* Available package headers. */
+#define RPMDBI_HDLIST 6 /* (rpmgi) Header list. */
+#define RPMDBI_ARGLIST 7 /* (rpmgi) Argument list. */
+#define RPMDBI_FTSWALK 8 /* (rpmgi) File tree walk. */
/**
* Tags identify data in package headers.
diff --git a/lib/rpmts.h b/lib/rpmts.h
index f1cf55c9e..f209c7d39 100644
--- a/lib/rpmts.h
+++ b/lib/rpmts.h
@@ -576,7 +576,7 @@ rpmtsType rpmtsGetType(rpmts ts)
* RPMTRANS_TYPE_AUTOROLLBACK
*
* @param ts transaction set
- * @param rollback rpmtsType
+ * @param type transaction type
* @return void
*/
void rpmtsSetType(rpmts ts, rpmtsType type)
diff --git a/lib/signature.h b/lib/signature.h
index 036af89fc..df81ca456 100644
--- a/lib/signature.h
+++ b/lib/signature.h
@@ -79,9 +79,9 @@ int rpmAddSignature(Header sig, const char * file,
/**
* Possible actions for rpmLookupSignatureType()
*/
-#define RPMLOOKUPSIG_QUERY 0 /*!< Lookup type in effect */
-#define RPMLOOKUPSIG_DISABLE 1 /*!< Disable (--sign was not given) */
-#define RPMLOOKUPSIG_ENABLE 2 /*!< Re-enable %_signature */
+#define RPMLOOKUPSIG_QUERY 0 /* Lookup type in effect */
+#define RPMLOOKUPSIG_DISABLE 1 /* Disable (--sign was not given) */
+#define RPMLOOKUPSIG_ENABLE 2 /* Re-enable %_signature */
/** \ingroup signature
* Return type of signature needed for signing/building.
diff --git a/lib/transaction.c b/lib/transaction.c
index 935ecdfa0..09d5319b0 100644
--- a/lib/transaction.c
+++ b/lib/transaction.c
@@ -1091,15 +1091,15 @@ static rpmRC _rpmtsRollback(rpmts rollbackTransaction)
* be made more efficient (only create on per running transaction).
* @param ts rpm transaction
* @param te transaction element
* @return hdrp Repackaged header
* @return fn Repackaged package's path (transaction key)
* @return RPMRC_NOTFOUND or RPMRC_OK
*/
static rpmRC getRepackageHeaderFromTE(rpmts ts, rpmte te,
/*@out@*/ /*@null@*/ Header *hdrp,
- /*@out@*/ /*@null@*/ const char **fn)
+ /*@out@*/ /*@null@*/ const char **fnp)
/*@globals rpmGlobalMacroContext, h_errno, fileSystem, internalState @*/
- /*@modifies ts, *hdrp, *fn,
+ /*@modifies ts, *hdrp, *fnp,
rpmGlobalMacroContext, fileSystem, internalState @*/
{
int_32 tid;
@@ -1122,8 +1122,8 @@ static rpmRC getRepackageHeaderFromTE(rpmts ts, rpmte te,
/* Set header pointer to null if its not already */
if (hdrp)
*hdrp = NULL;
- if (fn)
- *fn = NULL;
+ if (fnp)
+ *fnp = NULL;
/* Get the TID of the current transaction */
tid = rpmtsGetTid(ts);
@@ -1213,8 +1213,8 @@ exit:
if (hdrp != NULL)
*hdrp = headerLink(h);
/*@-branchstate@*/
- if (fn != NULL)
- *fn = rp;
+ if (fnp != NULL)
+ *fnp = rp;
else
rp = _free(rp);
/*@=branchstate@*/
@@ -1091,15 +1091,15 @@ static rpmRC _rpmtsRollback(rpmts rollbackTransaction)
* @param ts rpm transaction
* @param te transaction element
- * @return hdrp Repackaged header
- * @return fn Repackaged package's path (transaction key)
+ * @retval hdrp Repackaged header
+ * @retval fnp Repackaged package's path (transaction key)
* @return RPMRC_NOTFOUND or RPMRC_OK
*/